
# This file was generated by 'versioneer.py' (0.18) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2018-01-05T08:46:24-0600",
 "dirty": false,
 "error": null,
 "full-revisionid": "c449c869922bd46656a8cd8331a822cd8cc64ebb",
 "version": "1.0.2+2.gc449c8699"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
